#!/bin/sh
set -e

SOURCE_DIR=$(realpath $(dirname "${0}"))/basic

# Install packages
apk --no-cache add curl bridge e2fsprogs-extra gettext iptables kbd-misc libressl lxc python3 py3-bcrypt py3-cffi py3-dnspython py3-jinja2 py3-requests py3-six py3-werkzeug nginx util-linux
if [ ${DEBUG:-0} -eq 1 ]; then
    # Install some utilities for DEBUG mode
    apk --no-cache add git file htop less openssh-server openssh-sftp-server
fi

# Copy root profile files and settings for DEBUG mode
if [ ${DEBUG:-0} -eq 1 ]; then
    mkdir -p /root/.config/htop /root/.ssh
    cp ${SOURCE_DIR}/root/.profile /root/.profile
    cp ${SOURCE_DIR}/root/.ssh/authorized_keys /root/.ssh/authorized_keys
    cp ${SOURCE_DIR}/root/.config/htop/htoprc /root/.config/htop/htoprc
fi

# Copy boot configuration
cp ${SOURCE_DIR}/boot/extlinux.conf /boot/extlinux.conf
cp ${SOURCE_DIR}/boot/vm.txt /boot/vm.txt
cp ${SOURCE_DIR}/etc/inittab /etc/inittab
cp ${SOURCE_DIR}/sbin/extend-disk /sbin/extend-disk
cp ${SOURCE_DIR}/sbin/vmtty /sbin/vmtty
>/etc/motd

# Enable support for Czech characters
cp ${SOURCE_DIR}/etc/rc.conf /etc/rc.conf
cp ${SOURCE_DIR}/etc/conf.d/consolefont /etc/conf.d/consolefont

# Configure NTP client
cp ${SOURCE_DIR}/etc/conf.d/ntpd /etc/conf.d/ntpd

# Configure networking
cp ${SOURCE_DIR}/etc/conf.d/iptables /etc/conf.d/iptables
cp ${SOURCE_DIR}/etc/iptables/rules-save /etc/iptables/rules-save
cp ${SOURCE_DIR}/etc/network/interfaces /etc/network/interfaces
service networking restart
service iptables restart
echo -e "172.17.0.1 host\n172.17.0.1 postfix" >>/etc/hosts

# Download and configure acme.sh
mkdir /etc/acme.sh.d
wget https://raw.githubusercontent.com/Neilpang/acme.sh/master/acme.sh -O /usr/bin/acme.sh
sed -i 's|$HOME/.$PROJECT_NAME|/etc/acme.sh.d|' /usr/bin/acme.sh
chmod +x /usr/bin/acme.sh

# Copy VMMgr resources
cp ${SOURCE_DIR}/etc/init.d/vmmgr /etc/init.d/vmmgr
rc-update -u
cp -r ${SOURCE_DIR}/srv/vm /srv/vm
ln -s /srv/vm/cli.py /usr/bin/vmmgr

# Create a self-signed certificate
vmmgr create-selfsigned

# Configure nginx
cp ${SOURCE_DIR}/etc/nginx/nginx.conf /etc/nginx/nginx.conf

# Configure services
for SERVICE in consolefont crond iptables nginx ntpd lxc swap vmmgr; do
    rc-update add ${SERVICE} boot
    service ${SERVICE} start
done

# Configure services for DEBUG mode
if [ ${DEBUG:-0} -eq 1 ]; then
    rc-update add sshd boot
    service sshd start
fi

# Set dummy host and generate related files
vmmgr update-host spotter.vm 443
